<?php
session_start();
include 'db_connect.php';
mysqli_set_charset($conn, 'utf8');

// Fonction pour sécuriser les entrées
function secure($data) {
    global $conn;
    return mysqli_real_escape_string($conn, htmlspecialchars($data));
}

// Fonction pour gérer les erreurs SQL
function handleSQLError($conn, $message = '') {
    error_log("Erreur MySQL: " . mysqli_error($conn) . " - " . $message);
    return false;
}

// Vérification si l'utilisateur est connecté
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit();
}

// Date du jour
$today = date('Y-m-d');
$user_id = $_SESSION['user_id'];

// Initialisation des variables
$total_gros = 0;
$total_detail = 0;
$result_ventes = null;

try {
    // Requête pour calculer le total des ventes de type "gros"
    $query_gros = "SELECT COALESCE(SUM(dv.quantite * dv.prix_unitaire), 0) as total_gros
                   FROM details_vente dv
                   INNER JOIN products p ON dv.nom_produit = p.stock
                   WHERE DATE(dv.date_heure) = ?
                   AND dv.user_id = ?
                   AND p.type = 'gros'";

    $stmt_gros = $conn->prepare($query_gros);
    if ($stmt_gros) {
        $stmt_gros->bind_param('si', $today, $user_id);
        if ($stmt_gros->execute()) {
            $result = $stmt_gros->get_result();
            if ($row = $result->fetch_assoc()) {
                $total_gros = $row['total_gros'];
            }
        }
        $stmt_gros->close();
    } else {
        handleSQLError($conn, 'Préparation requête gros');
    }

    // Requête pour calculer le total des ventes de type "detail"
    $query_detail = "SELECT COALESCE(SUM(dv.quantite * dv.prix_unitaire), 0) as total_detail
                     FROM details_vente dv
                     INNER JOIN products p ON dv.nom_produit = p.stock
                     WHERE DATE(dv.date_heure) = ?
                     AND dv.user_id = ?
                     AND p.type = 'detail'";

    $stmt_detail = $conn->prepare($query_detail);
    if ($stmt_detail) {
        $stmt_detail->bind_param('si', $today, $user_id);
        if ($stmt_detail->execute()) {
            $result = $stmt_detail->get_result();
            if ($row = $result->fetch_assoc()) {
                $total_detail = $row['total_detail'];
            }
        }
        $stmt_detail->close();
    } else {
        handleSQLError($conn, 'Préparation requête detail');
    }

    // Requête pour obtenir toutes les ventes de la journée
    $query_ventes = "SELECT p.nom as nom_produit, 
                            p.type as type_produit,
                            dv.quantite,
                            dv.prix_unitaire,
                            (dv.quantite * dv.prix_unitaire) as total
                     FROM details_vente dv
                     INNER JOIN products p ON dv.nom_produit = p.stock
                     WHERE DATE(dv.date_heure) = ?
                     AND dv.user_id = ?
                     ORDER BY dv.date_heure DESC";

    $stmt_ventes = $conn->prepare($query_ventes);
    if ($stmt_ventes) {
        $stmt_ventes->bind_param('si', $today, $user_id);
        if ($stmt_ventes->execute()) {
            $result_ventes = $stmt_ventes->get_result();
        }
        $stmt_ventes->close();
    } else {
        handleSQLError($conn, 'Préparation requête ventes');
    }

} catch (Exception $e) {
    error_log("Erreur : " . $e->getMessage());
}
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <title>Gestion des Ventes</title>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.6.0/jquery.min.js"></script>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/4.1.1/animate.min.css" />
    <style>
        :root {
            --primary-color: #2c3e50;
            --secondary-color: #34495e;
            --accent-color: #517398;
            --success-color: #2ecc71;
            --error-color: #e74c3c;
        }

        body {
            font-family: 'Segoe UI', Arial, sans-serif;
            margin: 0;
            padding: 0;
            background-color: #f5f6fa;
        }
        
        .top-nav {
            background-color: var(--primary-color);
            padding: 15px;
            color: white;
        }
        
        .top-nav a {
            color: white;
            text-decoration: none;
            margin-right: 20px;
            font-size: 14px;
            padding: 5px 10px;
            border-radius: 4px;
            transition: background-color 0.3s;
        }
        
        .top-nav a:hover {
            background-color: rgba(255, 255, 255, 0.1);
        }
        
        .sidebar {
            width: 200px;
            background-color: var(--secondary-color);
            color: white;
            height: 100vh;
            position: fixed;
            padding-top: 20px;
        }

        .main-content {
            margin-left: 210px;
            padding: 30px;
            animation: fadeIn 0.5s ease;
        }

        .form-container {
            background: white;
            padding: 25px;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0,0,0,0.1);
            margin-bottom: 30px;
            animation: slideIn 0.5s ease;
        }

        .form-group {
            margin-bottom: 20px;
            position: relative;
        }

        .form-group label {
            display: block;
            margin-bottom: 8px;
            color: var(--primary-color);
            font-weight: 500;
            transition: all 0.3s ease;
        }

        .form-control {
            width: 100%;
            padding: 12px;
            border: 1px solid #ddd;
            border-radius: 4px;
            transition: all 0.3s ease;
            box-sizing: border-box;
        }

        .form-control:focus {
            border-color: var(--accent-color);
            box-shadow: 0 0 0 2px rgba(81,115,152,0.2);
            outline: none;
        }

        .btn {
            background-color: var(--accent-color);
            color: white;
            padding: 12px 24px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            transition: all 0.3s ease;
            font-weight: 500;
        }

        .btn:hover {
            background-color: #3d5876;
            transform: translateY(-1px);
        }

        .search-section {
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0,0,0,0.1);
            margin-bottom: 30px;
            animation: slideIn 0.5s ease;
        }

        .date-picker {
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
            margin-right: 10px;
            width: 200px;
        }

        table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 20px;
            background: white;
            box-shadow: 0 2px 10px rgba(0,0,0,0.1);
            border-radius: 8px;
            overflow: hidden;
            animation: slideIn 0.5s ease;
        }

        th {
            background-color: var(--accent-color);
            color: white;
            padding: 15px;
            text-align: left;
        }

        td {
            padding: 12px 15px;
            border-bottom: 1px solid #eee;
        }

        tr:hover {
            background-color: #f8f9fa;
        }

        .message {
            padding: 15px;
            border-radius: 4px;
            margin-bottom: 20px;
            animation: fadeIn 0.5s ease;
        }

        .success-message {
            background-color: #d4edda;
            color: #155724;
        }

        .error-message {
            background-color: #f8d7da;
            color: #721c24;
        }

        @keyframes fadeIn {
            from { opacity: 0; }
            to { opacity: 1; }
        }

        @keyframes slideIn {
            from { 
                opacity: 0;
                transform: translateY(20px);
            }
            to { 
                opacity: 1;
                transform: translateY(0);
            }
        }

        .loading {
            text-align: center;
            padding: 20px;
            display: none;
        }

        .loading:after {
            content: "...";
            animation: dots 1.5s steps(5, end) infinite;
        }

        @keyframes dots {
            0%, 20% { content: "."; }
            40% { content: ".."; }
            60% { content: "..."; }
            80%, 100% { content: ""; }
        }

        .total-box {
            width: 300px;
            padding: 20px;
            margin: 10px;
            border-radius: 5px;
            display: inline-block;
            color: white;
        }

        .gros {
            background-color: #2196F3;
        }

        .detail {
            background-color: #4CAF50;
        }
    </style>
</head>
<body>
    <div class="top-nav">
        <a href="page_caisse.php">Accueil</a>
        <a href="dashboard.php">Ventes</a>
        <a href="enregistre_depense.php">Dépenses</a>
        <a href="voir_point_caisse.php">Voir point</a>
        <a href="index.php">Déconnexion</a>
    </div>
    
    <div class="sidebar">
        <div class="logo-container">
            <img src="image/logo bleu.jpeg" alt="Logo" style="max-width: 100%; max-height: 150%;">
        </div>
        <div style="padding: 15px;">
            <input type="text" placeholder="Rechercher" style="width: 90%;" id="sidebarSearch">
        </div>
    </div>

    <div class="main-content">
        <h1>Ventes du <?php echo date('d/m/Y'); ?></h1>

        <!-- Rectangles de totaux -->
        <div class="total-box gros">
            <h2>Total Ventes Gros</h2>
            <p><?php echo number_format($total_gros, 2, ',', ' '); ?> fcfa</p>
        </div>

        <div class="total-box detail">
            <h2>Total Ventes Détail</h2>
            <p><?php echo number_format($total_detail, 2, ',', ' '); ?> fcfa</p>
        </div>

        <!-- Tableau des ventes -->
        <table>
            <thead>
                <tr>
                    <th>Produit</th>
                    <th>Type</th>
                    <th>Quantité</th>
                    <th>Prix unitaire</th>
                    <th>Total</th>
                </tr>
            </thead>
            <tbody>
                <?php 
                if ($result_ventes && $result_ventes->num_rows > 0):
                    while ($vente = $result_ventes->fetch_assoc()): 
                ?>
                    <tr>
                        <td><?php echo htmlspecialchars($vente['nom_produit']); ?></td>
                        <td><?php echo htmlspecialchars($vente['type_produit']); ?></td>
                        <td><?php echo $vente['quantite']; ?></td>
                        <td><?php echo number_format($vente['prix_unitaire'], 2, ',', ' '); ?> fcfa</td>
                        <td><?php echo number_format($vente['total'], 2, ',', ' '); ?> fcfa</td>
                    </tr>
                <?php 
                    endwhile;
                else: 
                ?>
                    <tr>
                        <td colspan="5" style="text-align: center;">Aucune vente enregistrée pour aujourd'hui</td>
                    </tr>
                <?php 
                endif; 
                ?>
            </tbody>
        </table>
    </div>

    <script>
    $(document).ready(function() {
        // Form submission with animation
        $('#expenseForm').on('submit', function(e) {
            e.preventDefault();
            
            $.ajax({
                type: 'POST',
                url: window.location.href,
                data: $(this).serialize(),
                success: function(response) {
                    const messageClass = response.success ? 'success-message' : 'error-message';
                    const message = $('<div class="message ' + messageClass + '">' + response.message + '</div>')
                        .hide()
                        .prependTo('#messageContainer')
                        .fadeIn();
                    
                    if(response.success) {
                        $('#expenseForm')[0].reset();
                        loadExpenses();
                    }
                    
                    setTimeout(() => message.fadeOut(() => message.remove()), 3000);
                }
            });
        });

        // Load expenses when dates change
        $('#startDate, #endDate').on('change', loadExpenses);
    });
    </script>
</body>
</html>
